@@ -35,23 +35,23 @@ class DiscoverPage : public QWizardPage
 Q_OBJECT
 
 public:
-    DiscoverPage(QWidget* parent = 0);
+    DiscoverPage(BlueWizard* parent = 0);
     virtual ~DiscoverPage();
 
     virtual void initializePage();
-    virtual void cleanupPage();
     virtual bool isComplete() const;
     virtual int nextId() const;
 private Q_SLOTS:
     void startScan();
     void deviceFound(const QVariantMap &deviceInfo);
     void itemSelected(QListWidgetItem* item);
-    void leavePage(int id);
+    void nameChanged(const QString& name);
 private:
     void stopScan();
 
 private:
     QMap<QString, QListWidgetItem*> m_itemRelation;
+    Device     *m_selectedDevice;
     BlueWizard *m_wizard;
 };
 
